from django.shortcuts import render, reverse
from django.views.generic import DetailView, ListView, CreateView
from django.http import HttpResponseRedirect
from django.contrib.auth.models import Group
from guardian.mixins import PermissionRequiredMixin, PermissionListMixin
from guardian.decorators import permission_required
from guardian.shortcuts import assign_perm
from . import models
from . import forms


class PublicKeyListView(PermissionListMixin, ListView):
    model = models.WireguardPublicKey
    permission_required = ['view_wireguardpublickey']


@permission_required('wireguard.add_wireguardpublickey')
def publickey_create(request):
    if request.method == 'POST':
        form = forms.PublicKeyCreateForm(request.POST)
        if form.is_valid():
            pk = models.WireguardPublicKey()
            pk.interface = form.cleaned_data['interface']
            pk.key = form.cleaned_data['key']
            pk.save()

            assign_perm('view_wireguardpublickey', request.user, pk)
            assign_perm('change_wireguardpublickey', request.user, pk)

            if form.cleaned_data['public']:
                any_user = Group.objects.get(name="any-user")
                assign_perm('view_wireguardpublickey', any_user, pk)
            return HttpResponseRedirect(reverse('wireguard-list'))

    # if a GET (or any other method) we'll create a blank form
    else:
        form = forms.PublicKeyCreateForm()

    return render(request,
                  'wireguard/wireguardpublickey_create.html',
                  {'form': form})
